==> haskell-monad-journal-0.8.1-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-FGG1GAmxmVLFQwgVbHyBMx
key: monad-journal-0.8.1-FGG1GAmxmVLFQwgVbHyBMx
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: 48eeeec73be3961bf12c652858e3d320
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.6.4/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-FGG1GAmxmVLFQwgVbHyBMx
depends:
    base-4.12.0.0 monad-control-1.0.2.3-3fyG0gh4gjL4D9yi94eZx mtl-2.2.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-LOZfHxBYQIt6vOmm2orzyE
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-4KKfg2MoIkeBQg0ZGylul
key: monad-journal-0.8.1-4KKfg2MoIkeBQg0ZGylul
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: f23a796e0354f508fbf5b86193e48ee8
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.6.4/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-4KKfg2MoIkeBQg0ZGylul
depends:
    base-4.12.0.0 monad-control-1.0.2.3-CbJ0M7iQh3tCaJfGqTvvKL
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-AYmaSZMrRmtI5aj5cOhHJQ
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
